[llvm] r192891 - Lit: LIT_PRESERVES_TMP should be aware of TMPDIR, too.

NAKAMURA Takumi geek4civic at gmail.com
Thu Oct 17 06:11:13 PDT 2013


Author: chapuni
Date: Thu Oct 17 08:11:13 2013
New Revision: 192891

URL: http://llvm.org/viewvc/llvm-project?rev=192891&view=rev
Log:
Lit: LIT_PRESERVES_TMP should be aware of TMPDIR, too.

TMPDIR is preferred in Unix.

Modified:
    llvm/trunk/utils/lit/lit/TestingConfig.py

Modified: llvm/trunk/utils/lit/lit/TestingConfig.py
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/utils/lit/lit/TestingConfig.py?rev=192891&r1=192890&r2=192891&view=diff
==============================================================================
--- llvm/trunk/utils/lit/lit/TestingConfig.py (original)
+++ llvm/trunk/utils/lit/lit/TestingConfig.py Thu Oct 17 08:11:13 2013
@@ -35,13 +35,14 @@ class TestingConfig:
                     'TMP' : os.environ.get('TMP',''),
                     })
 
         # The option to preserve TMP (and TEMP).
         # This is intended to check how many temporary files would be generated
-        # in automated builders.
+        # (and be not cleaned up) in automated builders.
         if os.environ.has_key('LIT_PRESERVES_TMP'):
             environment.update({
                     'TEMP' : os.environ.get('TEMP',''),
                     'TMP' : os.environ.get('TMP',''),
+                    'TMPDIR' : os.environ.get('TMPDIR',''),
                     })
 
         # Set the default available features based on the LitConfig.
@@ -35,13 +35,14 @@ class TestingConfig:
                     })
 
-        # The option to preserve TMP (and TEMP).
+        # The option to preserve TEMP, TMP, and TMPDIR.
         # This is intended to check how many temporary files would be generated





More information about the llvm-commits mailing list